@@ -25,6 +25,7 @@ from os.path import exists as pathexists
 from os import path
 from cl_utils import isMount, genpassword, getAvailableX11Drivers, \
                      listDirectory,isPkgInstalled
+from utils import ip
 from encrypt import getHash
 
 class fillVars(varsShare):
@@ -145,15 +146,9 @@ class fillVars(varsShare):
         IPs = []
         netInterfaces=self.Get("os_net_interfaces")
         for i in netInterfaces:
-            res = self._runos("/sbin/ifconfig %s"%i)
-            if not res:
-                break
-            for line in res:
-                searchIP = re.search('addr:([0-9\.]+).+Bcast:', line)
-                if searchIP:
-                    # ip адрес
-                    ip = searchIP.groups()[0]
-                    IPs.append(ip)
+            ipaddr, mask = ip.receiveIpAndMask(i)
+            if ipaddr:
+                IPs.append(ipaddr)
         return ",".join(IPs)
 
     def get_os_net_interfaces(self):
@@ -162,40 +157,15 @@ class fillVars(varsShare):
 
     def get_os_net_allow(self):
         """Allowed networks"""
-
-        def getNet(ip, mask):
-            """By ip and mask get network"""
-            octetsMult = (0x1, 0x100, 0x10000, 0x1000000)
-            octetsIp = map(lambda x: int(x), ip.split("."))
-            octetsMask = map(lambda x: int(x), mask.split("."))
-            ipNumb = 0
-            for i in octetsMult:
-                ipNumb += octetsIp.pop()*i
-            maskNumb = 0
-            for i in octetsMult:
-                maskNumb += octetsMask.pop()*i
-            startIpNumber = maskNumb&ipNumb
-            x = startIpNumber
-            nMask = lambda y: len(filter(lambda x: y >> x &1 ,range(32)))
-            return "%s.%s.%s.%s/%s"\
-                   %(x>>24, x>>16&255, x>>8&255, x&255, nMask(maskNumb))
-
         networks=[]
         netInterfaces=self.Get("os_net_interfaces")
-        flagError = False
         for i in netInterfaces:
-            res = self._runos("/sbin/ifconfig %s"%i)
-            if not res:
-                flagError = True
-                break
-            for j in res:
-                s_ip=re.search('addr:([0-9\.]+).+Bcast:.+Mask:([0-9\.]+)' ,j)
-                if s_ip:
-                    ip, mask = s_ip.groups()
-                    networks.append(getNet(ip, mask))
-        if flagError:
-            return ""
-        return ",".join(networks)
+            ipaddr, mask = ip.receiveIpAndMask(i)
+            if ipaddr and mask:
+                networks.append(ip.getIpNet(ipaddr, mask))
+            else:
+                networks.append("")
+        return ",".join(filter(lambda x:x,networks))
 
     def get_os_arch_machine(self):
         """Processor architecture"""
@@ -418,7 +388,8 @@ class fillVars(varsShare):
         xorg_conf = '/etc/X11/xorg.conf'
         # Try analize Xorg.{DISPLAY}.log
         display = os.environ.get('DISPLAY')
-        list_avialable_drivers = getAvailableX11Drivers()
+        list_avialable_drivers = \
+            getAvailableX11Drivers(prefix=self.Get('cl_chroot_path'))
         if display and list_avialable_drivers:
             reDriver = re.compile('|'.join(map(lambda x: "%s_drv.so"%x,
                                                list_avialable_drivers)))
