@@ -805,6 +805,27 @@ def listDirectory(directory,fullPath=False):
         pass
     return []
 
+def readLinesFile(filename):
+    """Read file by line"""
+    try:
+        if path.exists(filename):
+            for line in open(filename,'r'):
+                yield line.rstrip('\n')
+    except (OSError,IOError):
+        pass
+    finally:
+        raise StopIteration
+
+def readFile(filename):
+    """Read whole file or return empty string"""
+    try:
+        if path.exists(filename):
+            return open(filename,'r').read()
+    except (OSError,IOError):
+        pass
+    finally:
+        return ""
+
 def getUUIDDict(revers=False):
     """Get dict UUID -> dev"""
     devuuid = '/dev/disk/by-uuid'
@@ -850,9 +871,26 @@ def getProgPath(progname):
     else:
         return False
 
+def checkUtils(*utils):
+    """Check utils and exit if it not found"""
+    retval = []
+    for util in utils:
+        utilPath = getProgPath(util)
+        if not utilPath:
+            cl_overriding.printERROR(_("Command not found '%s'")%
+                                     path.basename(util))
+            cl_overriding.exit(1)
+        retval.append(utilPath)
+    if len(retval) == 1:
+        return retval[0]
+    else:
+        return retval
+
 reVerSplit = re.compile(r"^(.*?)-(([^-]+?)(?:-(r\d+))?)(?:.(tbz2))?$",re.S)
 def reVerSplitToPV(x):
     """Convert match from reVerSplit to PV hash"""
+    if type(x) == str:
+        x = reVerSplit.search(x)
     if x:
         match = x.groups()
         return {'PN':match[0],
@@ -900,12 +938,14 @@ def isPkgInstalled(pkg,prefix='/'):
     if "/" in pkg:
         category,op,pkg = pkg.partition('/')
         return bool(
-               filter(lambda x:x.startswith(pkg),
-               listDirectory(path.join(pkgDir,category))))
+               filter(lambda x:x['PN'] == pkg,
+               map(reVerSplitToPV,
+               listDirectory(path.join(pkgDir,category)))))
     else:
         return bool(
-               filter(lambda x: filter(lambda y:y.startswith(pkg),
-                                listDirectory(x)),
+               filter(lambda x: filter(lambda y:y['PN'] == pkg,
+                                map(reVerSplitToPV,
+                                listDirectory(x))),
                listDirectory(pkgDir,fullPath=True)))
 
 def getPkgActiveUses(fullpkg):
@@ -925,9 +965,45 @@ def getSquashList():
         return map(lambda x:{"lzma":"xz"}.get(x,x),
                list(set(usesSquashFs) & wantMethod))
 
-def getAvailableX11Drivers():
+def getAvailableX11Drivers(prefix="/"):
     """Get available x11 drivers"""
-    xorg_modules_dir = '/usr/lib/xorg/modules/drivers'
-    return map(lambda x: x[:-7],
+    distfiles = path.join(prefix,'usr/portage/distfiles')
+    xorg_modules_dir = path.join(prefix,'usr/lib/xorg/modules/drivers')
+    return list(set(
+           map(lambda x:'fglrx' if x.startswith('ati-driver') else "nvidia",
+           filter(lambda x:x.startswith('ati-driver-installer') or
+                           x.startswith('NVIDIA-Linux'),
+           listDirectory(distfiles))) + \
+           map(lambda x: x[:-7],
            filter(lambda x:x.endswith('_drv.so'),
-           listDirectory(xorg_modules_dir)))
+           listDirectory(xorg_modules_dir)))))
+
+def lspci(filtername=None,shortInfo=False):
+    """Get hash of lspci, filtred by filtername. If shortInfo, then
+    type,vendor and name get only first word
+
+    pcidata(domain,bus,slot,func)
+    'type'
+    'vendor'
+    'name'"""
+    reData = re.compile(r'(\S+)\s"([^"]+)"\s+"([^"]+)"\s+"([^"]+)"',re.S)
+    if filtername:
+        filterfunc = lambda x: filtername in x
+    else:
+        filterfunc = lambda x:x
+    if shortInfo:
+        sfunc = lambda x:x.partition(" ")[0]
+    else:
+        sfunc = lambda x:x
+    lspciProg = checkUtils('/usr/sbin/lspci')
+    processLsPci = process(lspciProg,"-m")
+    retData = {}
+    for device in map(lambda x:x.groups(),
+                  filter(lambda x:x,
+                  map(reData.search,
+                  filter(filterfunc,
+                  processLsPci)))):
+        retData[device[0]] = {'type':sfunc(device[1]),\
+                              'vendor':sfunc(device[2]),\
+                              'name':sfunc(device[3])}
+    return retData
