@@ -109,6 +109,9 @@ class Data:
     # motherboard vendor
     hr_board_vendor = {'hide':True}
 
+    # cdrom device
+    hr_cdrom_set = {}
+
     # processors count
     hr_cpu_num = {'hide':True}
 
@@ -117,7 +120,10 @@ class Data:
 
     # system version
     os_linux_ver = {'hide':True}
- 
+
+    # system version
+    os_linux_build = {'hide':True}
+
     # user login
     ur_login = {'hide':True}
 
